﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows.Input;
using Microsoft.Practices.Prism.Mvvm;
using Syncfusion.UI.Xaml.Utils;
using SyncfusionBindingError.Entities;

namespace SyncfusionBindingError.ViewModel
{
    class SecondPageViewModel : BindableBase
    {
        private IList<PriceListGrid> realPriceList;
        public IList<PriceListGrid> RealPriceList
        {
            get { return this.realPriceList; }
            set
            {
                SetProperty(ref realPriceList, value);
            }
        }

        private PriceListGrid _priceGridSelectedProperty;
        public PriceListGrid PriceGridSelected
        {
            get { return _priceGridSelectedProperty; }
            set
            {
                SetProperty(ref _priceGridSelectedProperty, value);
            }
        }
        public ICommand ReloadCommand { get; set; }

        public SecondPageViewModel()
        {
            ReloadCommand = new DelegateCommand(RealoadList);

            dynamic price1 = new System.Dynamic.ExpandoObject();
            price1.PriceNo = (byte)1;
            price1.PriceUID = Guid.NewGuid();
            price1.ComputedAmount = 1;
            price1.Name = "Price1";

            dynamic price2 = new System.Dynamic.ExpandoObject();
            price2.PriceNo = (byte)2;
            price2.PriceUID = Guid.NewGuid();
            price2.ComputedAmount = 2;
            price2.Name = "Price2";

            dynamic price3 = new System.Dynamic.ExpandoObject();
            price3.PriceNo = (byte)3;
            price3.PriceUID = Guid.NewGuid();
            price3.ComputedAmount = 3;
            price3.Name = "Price3";

            var priceList = new List<dynamic>(){price1,price2,price3};
            var overwrittenPrices = new List<dynamic>() { price1, price2, price3 };

            GetPriceListGrid(priceList, overwrittenPrices);
        }

        private void RealoadList(object sender)
        {
            dynamic price1 = new System.Dynamic.ExpandoObject();
            price1.PriceNo = (byte)4;
            price1.PriceUID = Guid.NewGuid();
            price1.ComputedAmount = 4;
            price1.Name = "Price4";

            dynamic price2 = new System.Dynamic.ExpandoObject();
            price2.PriceNo = (byte)5;
            price2.PriceUID = Guid.NewGuid();
            price2.ComputedAmount = 5;
            price2.Name = "Price5";

            dynamic price3 = new System.Dynamic.ExpandoObject();
            price3.PriceNo = (byte)6;
            price3.PriceUID = Guid.NewGuid();
            price3.ComputedAmount = 6;
            price3.Name = "Price6";

            var priceList = new List<dynamic>() { price1, price2, price3 };
            var overwrittenPrices = new List<dynamic>() { price1, price2, price3 };

            GetPriceListGrid(priceList, overwrittenPrices);
        }

        private void GetPriceListGrid(IEnumerable<dynamic> priceLists, IEnumerable<dynamic> overwrittenPrices)
        {
            var newList = new ObservableCollection<PriceListGrid>();

            if (priceLists == null || overwrittenPrices == null) return;

            foreach (var price in priceLists)
            {
                var overwritePrice = overwrittenPrices.FirstOrDefault(x => x.PriceNo == price.PriceNo);

                var priceList = new PriceListGrid("", price.PriceUID)
                {
                    ComputedPrice = price.ComputedAmount.ToString("C"),
                    ComputedPriceDate = DateTime.Now,
                    CurrentPrice = price.ComputedAmount,
                    NewPriceString = price.ComputedAmount.ToString("G29"),
                    ForcedFlag = 1,
                    PriceNo = price.PriceNo,
                    PriceNoAndName = string.Format("{0} {1} {2}", price.PriceNo, "-", price.Name),
                    ColorIfForced = "Black"
                };
                newList.Add(priceList);

            }

            this.RealPriceList = newList;
            this.PriceGridSelected = this.RealPriceList.FirstOrDefault();

        }
    }

    
}
